@@ -414,7 +414,7 @@ class Microservices(BaseClass, ABC):
                 },
                 "meta": {
                     "id_transaction": dataResponse['metadata']['id_transaction'],
-                    "status": 'ERROR' if errorCode < 0 else 'SUCCESS'
+                    "status": 'ERROR' if errorCode < 0 or errorCode > 0 else 'SUCCESS'
                 }
             }
 
